*NOTA INTRODUCTORIA:
**Para ejecutar este análisis el usuario debe disponer de los datos individuales de la ECEPOV-21 que puede encontrar en "Torrado, J.M. (2024). Montaje y base de datos final de la Encuesta de Características Esenciales de la Población y las Viviendas 2021 para STATA. Departamento de Sociología, Universidad de Granada, Granada".

********************************************************************************
*********************GENERACIÓN DE BASE DE DATOS POR PAREJAS********************
********************************************************************************
drop if TIPOHOGAR<3
drop if TIPOHOGAR>4
drop if SEXO_PAREJA!=1
rename *, lower
****NOTA: Aunque la llamamos base de datos por parejas, debe tenerse en cuenta que hay un registro por cada miembro de la pareja, esto es porque es necesario para calcular determinadas características de la parejas, algo que hacemos en la sintaxis que sigue. Para utilizarla como una base de datos exclusivamente de parejas es necesario ejecutar los análisis con el filtro "if sexo==1" ó lo que es lo mismo "if sexo==2"


********************************************************************************
******************************GRÁFICOS 1 Y 2************************************
********************************************************************************
tab tdomest_h dif_tdomest_cat if sexo==1
tab tdomest_m dif_tdomest_cat if sexo==1


********************************************************************************
***************************MODELO LOGÍSTICO TABLA 1*****************************
********************************************************************************


*****************************************************
*Variable dependiente: reparto del trabajo doméstico*
*****************************************************

gen tdomest_hombre= cond(sexo==1, tdomest, .)
gen tdomest_mujer= cond(sexo==2, tdomest, .)
egen tdomest_h=max(tdomest_hombre),by(iden)
egen tdomest_m=max(tdomest_mujer),by(iden)
gen dif_tdomest=tdomest_h-tdomest_m
tab dif_tdomest
drop tdomest_hombre tdomest_mujer


recode dif_tdomest (0=1) (-3/-1=2) (1/3=3), gen (dif_tdomest_cat)
label define dif_tdomest_cat 1"Igualdad" 2"Más el hombre" 3"Más la mujer"
label values dif_tdomest_cat dif_tdomest_cat

recode dif_tdomest_cat (1=1) (else=0), gen (_igual_reparto) 
recode dif_tdomest_cat (3=1) (else=0), gen (_mujer_cuidadora) 
recode dif_tdomest_cat (2=1) (else=0), gen (_hombre_cuidador) 


**************************
*Variables independientes*
**************************

**Edad
**Edad del hombre y la mujer
gen edad_hombre= cond(sexo==1, edad, .)
gen edad_mujer= cond(sexo==2, edad, .)
egen edad_h=max(edad_hombre), by(iden)
egen edad_m=max(edad_mujer), by(iden)
drop edad_hombre edad_mujer
gen edad_h2=edad_h*edad_h
gen edad_m2=edad_m*edad_m


**Diferencia de edad (hombre respecto a la mujer)
gen dif_edad=edad_h-edad_m

gen dif_edad1=.
replace dif_edad1=1 if edad_h==edad_m
replace dif_edad1=2 if edad_h>edad_m
replace dif_edad1=3 if edad_h<edad_m
recode dif_edad1 (1=1)(else=0), gen (_mismaedad)
recode dif_edad1 (2=1)(else=0), gen (_hombremayor)
recode dif_edad1 (3=1)(else=0), gen (_mujermayor)

**Hijos
order edad_hijo_menor_intervalo nhijo_less16 nhijo_less18 nhijo_more18, last
order hijos_nucleo, last
recode edad_hijo_menor_intervalo (1=1) (else=0), gen (_menos2anos)
recode edad_hijo_menor_intervalo (2=1) (else=0), gen (_3a6anos)
recode edad_hijo_menor_intervalo (3=1) (else=0), gen (_7a11anos)
recode edad_hijo_menor_intervalo (4=1) (else=0), gen (_12a16anos)
recode edad_hijo_menor_intervalo (5=1) (else=0), gen (_a17a18anos)
recode edad_hijo_menor_intervalo (6=1) (else=0), gen (_mas18anos)
recode edad_hijo_menor_intervalo (.=0)

**Tipo de unión
order union_pareja, last
recode union_pareja (1=1) (else=0), gen (_casados)
recode union_pareja (2=1) (else=0), gen (_solteros)
recode union_pareja (3=1) (else=0), gen (_reconstituida)

**Años viviendo juntos
recode anoconvicasad (.=0)
recode anoconvipar (.=0)
recode anoec (.=0)
gen anos_conviv=anoconvicasad+anoconvipar
replace anos_conviv=anoec if anos_conviv==0
gen anos_conviv_f=2021-anos_conviv
recode anos_conviv_f (2021=0)
**Nivel educativo
**recodificamos (para simplificarlos) los estudios
recode estudios (1/3=1) (4=2) (5/8=3) (9/max=4), gen (estudios_r)
label define estudios_r 1"Primaria o menos" 2"Secundaria" 3"Bach o FP" 4"Superiores"
label values estudios_r estudios_r
tab estudios estudios_r
**estudios de la mujer y del hombre
gen estudios_hombre=cond(sexo==1, estudios_r, .)
gen estudios_mujer=cond(sexo==2, estudios_r, .)
egen estudios_h=max(estudios_hombre), by(iden)
egen estudios_m=max(estudios_mujer), by(iden)
label values estudios_h estudios_r
label values estudios_m estudios_r
drop estudios_hombre estudios_mujer
**diferencia en nivel de estudios
gen dif_estud=estudios_h-estudios_m
recode dif_estud (0=1) (-3/-1=2) (1/3=3), gen (dif_estudios)
label define dif_estudios 1"Mismos estudios" 2"Mujer con más estudios" 3"Hombre con más estudios"
label values dif_estudios dif_estudios

gen dif_estud2=.
replace dif_estud2=1 if estudios_h==1 & estudios_m==1
replace dif_estud2=2 if estudios_h==2 & estudios_m==2
replace dif_estud2=3 if estudios_h==3 & estudios_m==3
replace dif_estud2=4 if estudios_h==4 & estudios_m==4
replace dif_estud2=5 if estudios_h>estudios_m
replace dif_estud2=6 if estudios_m>estudios_h
label define dif_estud2 1"Ambos primarios" 2"Ambos secundarios" 3"Ambos bac/fp" 4"Ambos superiores" 5"Hombre más estudios" 6"Mujer más estudios"
label values dif_estud2 dif_estud2
recode dif_estud2 (1=1) (else=0), gen (_ambos_primaria)
recode dif_estud2 (2=1) (else=0), gen (_ambos_sec)
recode dif_estud2 (3=1) (else=0), gen (_ambos_bachfp)
recode dif_estud2 (4=1) (else=0), gen (_ambos_univ)
recode dif_estud2 (5=1) (else=0), gen (_hombremasestud)
recode dif_estud2 (6=1) (else=0), gen (_mujermasestud)



**diferemcoa en nivel de estudios (ecepov)
order estudios_pareja, last
recode estudios_pareja (1=1) (else=0), gen (_ninguno_uni)
recode estudios_pareja (2=1) (else=0), gen (_uno_uni)
recode estudios_pareja (3=1) (else=0), gen (_dos_uni)


**Nacionalidad
order nacion_pareja, last
recode nacion_pareja (1=1) (else=0), gen (_ambos_esp)
recode nacion_pareja (2=1) (else=0), gen (_ambos_ext)
recode nacion_pareja (3=1) (else=0), gen (_españolconext)
recode nacion_pareja (4=1) (else=0), gen (_españolaconext)

**Relación con la actividad
**Simplificamos la relación con la actividad
recode sitlab (1=1) (2=2) (4/5=3) (3=4) (6/9=4), gen (rela)
label define rela 1"ocup tc" 2"ocup tp" 3"parado" 4"inactivo"
label values rela rela
**Relación con la actividad del hombre y la mujer
gen rela_hombre=cond(sexo==1, rela, .)
gen rela_mujer=cond(sexo==2, rela, .)
egen rela_h=max(rela_hombre),by(iden)
egen rela_m=max(rela_mujer),by(iden)
drop rela_hombre rela_mujer
label values rela_m rela
label  values rela_h rela
**Diferencia en relación con la actividad
order sitlab_pareja, last
gen dif_rela=.
replace dif_rela=1 if rela_h==1 & rela_m==1 
replace dif_rela=2 if rela_h==2 & rela_m==2
replace dif_rela=3 if rela_h==1 & rela_m==2
replace dif_rela=4 if rela_h==2 & rela_m==1
replace dif_rela=5 if rela_h>=3 & rela_m>=3
replace dif_rela=6 if rela_h<=2 & rela_m>=3
replace dif_rela=7 if rela_h>=3 & rela_m<=2
label define dif_rela 1"Ambos ocupados a tc" 2"Ambos ocupados a tp" 3"Hombre tc y Mujer tp" 4"Hombre tp y Mujer tc" 5"Ambos no trabajan" 6"Hombre trabaja, mujer no" 7"Mujer trabaja, hombre no"
label values dif_rela dif_rela
recode dif_rela (1=1) (else=0), gen(_ambos_tc)
recode dif_rela (2=1) (else=0), gen(_ambos_tp)
recode dif_rela (3=1) (else=0), gen(_hom_tc_muj_tp)
recode dif_rela (4=1) (else=0), gen(_hom_tp_muj_tc)
recode dif_rela (5=1) (else=0), gen(_ambos_no_trab)
recode dif_rela (6=1) (else=0), gen(_hom_trab_muj_no)
recode dif_rela (7=1) (else=0), gen(_muj_trab_hom_no)


**Ingresos del hogar
order ing,last
recode ing (1/3=1) (4/6=2) (7/9=3), gen(ing_r)
label define ing 1"Bajos" 2"Medios" 3"Altos"
label values ing_r ing
recode ing_r (1=1) (else=0), gen(_bajos)
recode ing_r (2=1) (else=0), gen(_medios)
recode ing_r (3=1) (else=0), gen(_altos)


**Servicio doméstico
recode servdomes (1/2=1) (3=0), gen (_serv_domes)
**Ayuda no remunerada 
recode ayudaext (1/2=1) (3=0), gen (_ayuda_ext)

**Zona de residencia
recode tam_muni (1=1) (else=0), gen (_menos50000)
recode tam_muni (2=1) (else=0), gen (_50000_100000)
recode tam_muni (3=1) (else=0), gen (_100000_500000)
recode tam_muni (4=1) (else=0), gen (_mas500000)

*************************************************
*************MODELOS LOGÍSTICOS******************
*************************************************
logit _mujer_cuidado _mismaedad _mujermayor _ambos_ext _españolconext _españolaconext _menos2anos _3a6anos _7a11anos _12a16anos _a17a18anos _mas18anos _solteros _reconstituida anos_conviv_f _uno_uni _dos_uni _ambos_tp _hom_tc_muj_tp _hom_tp_muj_tc _ambos_no_trab _hom_trab_muj_no _muj_trab_hom_no _medios _altos  _serv_domes _ayuda_ext _menos50000 _50000_100000 [pw=factor] if sexo==1, vce(robust)
fitstat
margins, dydx(dif_edad _ambos_ext _españolconext _españolaconext _menos2anos _3a6anos _7a11anos _12a16anos _a17a18anos _mas18anos _solteros _reconstituida anos_conviv_f _uno_uni _dos_uni _ambos_tp _hom_tc_muj_tp _hom_tp_muj_tc _ambos_no_trab _hom_trab_muj_no _muj_trab_hom_no _medios _altos  _serv_domes _ayuda_ext _menos50000 _50000_100000)

logit _hombre_cuidad dif_edad _ambos_ext _españolconext _españolaconext _menos2anos _3a6anos _7a11anos _12a16anos _a17a18anos _mas18anos _solteros _reconstituida anos_conviv_f _uno_uni _dos_uni _ambos_tp _hom_tc_muj_tp _hom_tp_muj_tc _ambos_no_trab _hom_trab_muj_no _muj_trab_hom_no _medios _altos  _serv_domes _ayuda_ext _menos50000 _50000_100000 [pw=factor] if sexo==1, vce(robust)
fitstat
margins, dydx(dif_edad _ambos_ext _españolconext _españolaconext _menos2anos _3a6anos _7a11anos _12a16anos _a17a18anos _mas18anos _solteros _reconstituida anos_conviv_f _uno_uni _dos_uni _ambos_tp _hom_tc_muj_tp _hom_tp_muj_tc _ambos_no_trab _hom_trab_muj_no _muj_trab_hom_no _medios _altos  _serv_domes _ayuda_ext _menos50000 _50000_100000)



